@@ -6,10 +6,9 @@ use Carp();
 
 use Rose::HTML::Util();
 
-use Rose::HTML::Form::Field::Group;
-our @ISA = qw(Rose::HTML::Form::Field::Group);
+use base 'Rose::HTML::Form::Field::Group';
 
-our $VERSION = '0.547';
+our $VERSION = '0.606';
 
 our $Debug = undef;
 
@@ -356,6 +355,8 @@ sub init_items
 
     foreach my $item ($self->items)
     {
+      local $item->{'auto_invalidate_parent'} = $self->auto_invalidate_parent;
+
       if($item->isa($group_class))
       {
         foreach my $subitem ($item->items)
